﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;
using Arction.WinForms.Charting;
using Arction.WinForms.Charting.Axes;
using Arction.WinForms.Charting.ChartManager;
using Arction.WinForms.Charting.SeriesXY;
using Arction.WinForms.Charting.Views.ViewXY;

namespace AL_XY_DEATH
{
    public partial class Form1 : Form
    {
        private int _seriesCount = 700;
        private int _pointCount = 4000;
        private Color[] _colors = {Color.Red, Color.Green, Color.Blue, Color.Purple, Color.Orange, Color.Yellow, Color.Turquoise, Color.LimeGreen};

        private LightningChartUltimate _chart;
        internal static ChartManager _chartManager = null;

        private Random _random = new Random();

        public Form1()
        {
            InitializeComponent();
            CreateChart();
        }

        private void Form1_Load(object sender, EventArgs e)
        {
            _chart.BeginUpdate();

            CreateSeries();
            _chart.ViewXY.ZoomToFit();

            _chart.EndUpdate();
        }

        void CreateChart()
        {
            if (_chartManager == null)
            {
                _chartManager = new ChartManager();
            }

            _chart = new LightningChartUltimate
            {
                ColorTheme = Arction.WinForms.Charting.ColorTheme.LightGray,
                BackColor = System.Drawing.Color.White,
                Title = { Visible = false },
                ChartManager = _chartManager,
                Dock = DockStyle.Fill,

                ViewXY = { LegendBox = { Visible = false } },
            };
            _chart.RenderOptions.DeviceType = RendererDeviceType.AutoPreferD11;
            _chart.RenderOptions.AntiAliasLevel = 5;

            _chart.BeginUpdate();
            _chart.ActiveView = ActiveView.ViewXY;

            var view = _chart.ViewXY;

            view.XAxes.Clear();
            view.YAxes.Clear();

            var xAxis = CreateXAxis(view);
            view.XAxes.Add(xAxis);

            var yAxis = CreateYAxis(view);
            view.YAxes.Add(yAxis);

            view.GraphBorderColor = Color.Transparent;
            view.GraphBordersOverSeries = false;

            this.Controls.Add(_chart);
            _chart.BringToFront();

            _chart.EndUpdate();
        }

        void CreateSeries()
        {
            var view = _chart.ViewXY;

            for (int i = 0; i<_seriesCount; i++)
            {
                var series = new PointLineSeries(view, view.XAxes[0], view.YAxes[0]);
                series.LineStyle.Color = _colors[i % _colors.Length];
                series.MouseInteraction = false;
                series.PointsOptimization = PointsRenderOptimization.LotsOfPixels;
                series.DisableDragToAnotherAxis = true;
                series.Tag = this;

                var xValues = new double[_pointCount];
                var yValues = new double[_pointCount];

                for (int j = 0; j < _pointCount; j++)
                {
                    xValues[j] = j / 10.0;
                    yValues[j] = i * Math.Sin(j / 0.023);

                    yValues[j] = _random.NextDouble() * 100;
                }

                series.SetValues(xValues, yValues);

                view.PointLineSeries.Add(series);
            }
        }


        #region CreateAxis

        protected AxisX CreateXAxis(ViewXY view)
        {
            var axis = new AxisX(view)
            {
                Title = { Visible = false },
                Units = { Visible = false },
                MajorDivTickStyle = { Alignment = Alignment.Far },
                MinorDivTickStyle = { Alignment = Alignment.Far },

                LabelsVisible = true,
            };

            CreateBaseAxis(axis, view);

            axis.Visible = true;

            return axis;
        }
        protected AxisY CreateYAxis(ViewXY view)
        {
            var axis = new AxisY(view)
            {
                Title = { Visible = false },
                Units = { Visible = false },
                MajorDivTickStyle = { Alignment = Alignment.Near },
                MinorDivTickStyle = { Alignment = Alignment.Near },

                LabelsVisible = true,
            };

            CreateBaseAxis(axis, view);
            //axis.SetRange(axisOptions.ViewYMin, axisOptions.ViewYMax);

            axis.Visible = true;

            return axis;
        }

        private void CreateBaseAxis(AxisXYBase axis, ViewXY view)
        {
            ApplyAxisOptions(axis, view);

            axis.MajorGrid.Visible = true;
            axis.MinorGrid.Visible = false; //first && _diagramOptions.GridActive;

            axis.KeepDivCountOnRangeChange = false; // Ticks bei Zoomen ändern

            axis.LabelTicksGap = 1;
            axis.MajorDivTickStyle.Color = Color.LightGray;
            axis.MajorDivTickStyle.LineLength = 6;

            axis.MinorDivTickStyle.Color = Color.LightGray;
            axis.MinorDivTickStyle.LineLength = 2;

            {
                axis.MajorGrid.Color = Color.Black;
                axis.MajorGrid.Pattern = LinePattern.Solid;

                axis.MinorGrid.Color = Color.Black;
                axis.MinorGrid.Pattern = LinePattern.Solid;

                //axis.AxisColor = Color.Black; //axisOptions.AxisColor;
                //axis.LabelsColor = Color.Black; //axisOptions.AxisColor;
            }

            axis.AxisThickness = 1;
            //axis.TickMarkWidth = 1;

            axis.ScaleNibs.Color = Color.Black;
            axis.ScaleNibs.Size.Width = 4;
            axis.ScaleNibs.Size.Height = 4;

            axis.MouseHighlight = MouseOverHighlight.None;
            axis.MouseScrolling = true;
            axis.MouseScaling = false; // ScaleNibs ausblenden

            //axis.MarginInner = 0;
            //axis.MarginOuter = first ? 5 : -21;

            //axis.MovedByMouse += axis_MovedByMouse;
            //axis.RangeChanged += axis_RangeChanged;

            axis.Tag = this;
        }

        #endregion
        #region ApplyAxisOptions

        protected void ApplyAxisOptions(AxisXYBase axis, ViewXY view)
        {
            if (axis is AxisX)
            {
                double minDt, maxDt;
                //axis.SetRange(axisOptions.ViewXMin, axisOptions.ViewXMax);

                axis.ValueType = AxisValueType.Number;
                axis.AutoFormatLabels = true;
            }
            else
            {
                double minDt, maxDt;
                //axis.SetRange(axisOptions.ViewYMin, axisOptions.ViewYMax);
                axis.ValueType = AxisValueType.Number;
                axis.AutoFormatLabels = true;
            }

            {
                axis.AxisColor = Color.Black;
                axis.AxisColor = Color.Black;
            }
            axis.LabelsColor = Color.Black;
            //axis.LabelsFont = new Font(_labelsFonts, _labelsFonts.Style);

            axis.MajorDivTickStyle.Color = Color.Black;
            //axis.MajorDivTickStyle.Color = Color.FromArgb(20, axisOptions.AxisColor);
            axis.MinorDivTickStyle.Color = Color.FromArgb(50, Color.Black);

            //axis.Reversed = _diagramOptions.AngleAxisRotation == AngleAxisRotation.ClockWise;
            //axis.AngleOrigin = _diagramOptions.GlobalOrientation;

            axis.MajorGrid.Color = Color.LightGray;
            axis.MinorGrid.Color = Color.LightGray;
            axis.ScaleNibs.Color = Color.Black;

        }
        
        #endregion

    }
}
